#include <QVBoxLayout>
#include <QtPlugin>
#include "SimpleExample.h"
#include "PluginServices.h"

/**  If the plugin doesn't load, the most likely reason is an undefined reference.
     To check this, set the environment variable CHECK_PLUGIN to the plugin file and
     call "make check-plugin" in the build-backend directory.
 */

#if QT_VERSION < 0x050000
Q_EXPORT_PLUGIN2( SimpleExamplePlugin, SimpleExample ); // ( PluginName, ClassName )
#endif

bool
SimpleExample::cubeOpened( PluginServices* service )
{
    this->service = service;

    widget_ = new QWidget();
    qlabel_ = new QLabel( "example string" );
    QVBoxLayout* layout = new QVBoxLayout();
    widget_->setLayout( layout );
    layout->addWidget( qlabel_ );

    service->addTab( SYSTEM, this );

    connect( service, SIGNAL( treeItemIsSelected( TreeType, TreeItem* ) ),
             this, SLOT( treeItemIsSelected( TreeType, TreeItem* ) ) );
    return true; // initialisation is ok => plugin should be shown
}

void
SimpleExample::cubeClosed()
{
    delete widget_;
}

/** set a version number, the plugin with the highest version number will be loaded */
void
SimpleExample::version( int& major, int& minor, int& bugfix ) const
{
    major  = 1;
    minor  = 0;
    bugfix = 0;
}

/** unique plugin name */
QString
SimpleExample::name() const
{
    return "Simple  Example Plugin";
}

QString
SimpleExample::getHelpText() const
{
    return "Just a simple example.";
}

/** widget that will be placed into the tab */
QWidget*
SimpleExample::widget()
{
    return widget_;
}

/** tab label */
QString
SimpleExample::label() const
{
    return "Example Plugin Label";
}

/** slot, which is called if a tree item is selected */
void
SimpleExample::treeItemIsSelected( TreeType type, TreeItem* item )
{
    QString txt = item->getName() + " " + QString::number( item->getValue() );
    qlabel_->setText( txt );
}
